==> materialish-0.11.0.tgz: package/es/menu/menu.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Ripple from '../ripple/ripple';
import Elevation from '../elevation/elevation';

var Menu = function (_Component) {
  _inherits(Menu, _Component);

  function Menu() {
    _classCallCheck(this, Menu);

    return _possibleConstructorReturn(this, (Menu.__proto__ || Object.getPrototypeOf(Menu)).apply(this, arguments));
  }

  _createClass(Menu, [{
    key: 'render',
    value: function render() {
      var _props = this.props,
          _props$className = _props.className,
          className = _props$className === undefined ? '' : _props$className,
          props = _objectWithoutProperties(_props, ['className']);

      return React.createElement(
        Elevation,
        { depth: 1 },
        React.createElement('ul', _extends({ className: 'mt-menu ' + className }, props))
      );
    }
  }]);

  return Menu;
}(Component);

export default Menu;


Menu.propTypes = {
  className: PropTypes.string
};

var Item = function (_Component2) {
  _inherits(Item, _Component2);

  function Item() {
    var _ref;

    var _temp, _this2, _ret;

    _classCallCheck(this, Item);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this2 = _possibleConstructorReturn(this, (_ref = Item.__proto__ || Object.getPrototypeOf(Item)).call.apply(_ref, [this].concat(args))), _this2), _this2.getRippleRef = function (component) {
      _this2.rippleComponent = component;
    }, _this2.onClick = function (e) {
      var onClick = _this2.props.onClick;


      if (_this2.rippleComponent) {
        _this2.rippleComponent.onClick(e);
      }

      if (onClick) {
        onClick();
      }
    }, _temp), _possibleConstructorReturn(_this2, _ret);
  }

  _createClass(Item, [{
    key: 'render',
    value: function render() {
      var _props2 = this.props,
          _props2$className = _props2.className,
          className = _props2$className === undefined ? '' : _props2$className,
          _props2$separator = _props2.separator,
          separator = _props2$separator === undefined ? false : _props2$separator,
          _props2$selected = _props2.selected,
          selected = _props2$selected === undefined ? false : _props2$selected,
          _props2$ripple = _props2.ripple,
          ripple = _props2$ripple === undefined ? true : _props2$ripple,
          children = _props2.children,
          props = _objectWithoutProperties(_props2, ['className', 'separator', 'selected', 'ripple', 'children']);

      return React.createElement(
        'div',
        _extends({
          className: 'mt-menu_item ' + (separator ? 'mt-menu_item-separator' : '') + ' ' + (selected ? 'mt-menu_item-selected' : '') + ' ' + className
        }, props, {
          onClick: this.onClick }),
        children,
        ripple && React.createElement(Ripple, { ref: this.getRippleRef })
      );
    }
  }]);

  return Item;
}(Component);

Item.propTypes = {
  className: PropTypes.string,
  separator: PropTypes.bool,
  selected: PropTypes.bool,
  ripple: PropTypes.bool
};

Menu.Item = Item;

==> materialish-0.14.1.tgz: package/es/menu/menu.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Ripple from '../ripple/ripple';
import Elevation from '../elevation/elevation';

var Menu = function (_Component) {
  _inherits(Menu, _Component);

  function Menu() {
    _classCallCheck(this, Menu);

    return _possibleConstructorReturn(this, (Menu.__proto__ || Object.getPrototypeOf(Menu)).apply(this, arguments));
  }

  _createClass(Menu, [{
    key: 'render',
    value: function render() {
      var _props = this.props,
          _props$className = _props.className,
          className = _props$className === undefined ? '' : _props$className,
          props = _objectWithoutProperties(_props, ['className']);

      return React.createElement(
        Elevation,
        { depth: 1 },
        React.createElement('ul', _extends({ className: 'mt-menu ' + className }, props))
      );
    }
  }]);

  return Menu;
}(Component);

export default Menu;


Menu.propTypes = {
  className: PropTypes.string
};

var Item = function (_Component2) {
  _inherits(Item, _Component2);

  function Item() {
    var _ref;

    var _temp, _this2, _ret;

    _classCallCheck(this, Item);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this2 = _possibleConstructorReturn(this, (_ref = Item.__proto__ || Object.getPrototypeOf(Item)).call.apply(_ref, [this].concat(args))), _this2), _this2.getRippleRef = function (component) {
      _this2.rippleComponent = component;
    }, _this2.onClick = function (e) {
      var onClick = _this2.props.onClick;


      if (_this2.rippleComponent) {
        _this2.rippleComponent.onClick(e);
      }

      if (onClick) {
        onClick();
      }
    }, _temp), _possibleConstructorReturn(_this2, _ret);
  }

  _createClass(Item, [{
    key: 'render',
    value: function render() {
      var _props2 = this.props,
          _props2$className = _props2.className,
          className = _props2$className === undefined ? '' : _props2$className,
          _props2$selected = _props2.selected,
          selected = _props2$selected === undefined ? false : _props2$selected,
          _props2$ripple = _props2.ripple,
          ripple = _props2$ripple === undefined ? true : _props2$ripple,
          children = _props2.children,
          props = _objectWithoutProperties(_props2, ['className', 'selected', 'ripple', 'children']);

      return React.createElement(
        'div',
        _extends({
          className: 'mt-menu_item ' + (selected ? 'mt-menu_item-selected' : '') + ' ' + className
        }, props, {
          onClick: this.onClick }),
        children,
        ripple && React.createElement(Ripple, { ref: this.getRippleRef })
      );
    }
  }]);

  return Item;
}(Component);

Item.propTypes = {
  className: PropTypes.string,
  selected: PropTypes.bool,
  ripple: PropTypes.bool
};

function Separator(props) {
  var className = props.className,
      rest = props.rest;


  return React.createElement('div', _extends({ className: 'mt-menu_separator ' + className }, rest));
}

Separator.propTypes = {
  className: PropTypes.string
};

Menu.Item = Item;
Menu.Separator = Separator;
